=== modified file 'ChangeLog'
--- ChangeLog	2006-07-24 14:32:01 +0000
+++ ChangeLog	2006-07-25 12:38:56 +0000
@@ -1,5 +1,13 @@
+2006-07-25  Szilveszter Farkas <Szilveszter.Farkas@gmail.com>
+
+    * olive-gtk: display error if python 2.4 not available (Mario Đanić)
+      (Fixed: #54014)
+    * olive-gtk: display error if pygtk2 (and glade) not available (Mario Đanić)
+      (Fixed: #54013)
+
 2006-07-24  Szilveszter Farkas <Szilveszter.Farkas@gmail.com>
 
+    * olive/frontend/gtk/push.py: display number of pushed revisions
     * olive.glade: improvements to the Commit dialog
     * olive/frontend/gtk/commit.py: merged Jelmer Vernooij's integration branch
       and some code from bzr-gtk (select files to commit)

=== modified file 'TODO'
--- TODO	2006-07-24 14:32:01 +0000
+++ TODO	2006-07-25 12:38:56 +0000
@@ -3,6 +3,9 @@
 
  - Be able to install into other locations than /usr (LarstiQ)
  - Investigate TortoiseSVN-like commit/add dialogs (LarstiQ)
-   http://samba.org/~jelmer/bzr/gcommit.png
+   http://samba.org/~jelmer/bzr/gcommit.png [DONE]
  - HIGify the interface (Matthieu Moy)
  - Consistent placement of buttons (Matthieu Moy)
+ - Display the count of pushed revisions on push (phanatic) [DONE]
+ - Display the commit file selector as a tree (so whole directories can be
+   toggled) (j-a-meinel)

=== modified file 'olive-gtk'
--- olive-gtk	2006-07-16 23:51:20 +0000
+++ olive-gtk	2006-07-25 12:38:56 +0000
@@ -16,7 +16,31 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import os
 import sys
+
+try:
+    version_info = sys.version_info
+except AttributeError:
+    version_info = 1, 5 # 1.5 or older
+
+REINVOKE = "__BZR_REINVOKE"
+NEED_VERS = (2, 4)
+KNOWN_PYTHONS = ('python2.4',)
+
+if version_info < NEED_VERS:
+    if not os.environ.has_key(REINVOKE):
+        # mutating os.environ doesn't work in old Pythons
+        os.putenv(REINVOKE, "1")
+        for python in KNOWN_PYTHONS:
+            try:
+                os.execvp(python, [python] + sys.argv)
+            except OSError:
+                pass
+    print >>sys.stderr, "bzr: error: cannot find a suitable python interpreter"
+    print >>sys.stderr, " (need %d.%d or later)" % NEED_VERS
+    sys.exit(1)
+
 try:
  	import pygtk
   	pygtk.require("2.0")
@@ -24,9 +48,14 @@
   	pass
 try:
 	import gtk
+	import gtk.glade
 except:
-	sys.exit(1)
-	
+    print >>sys.stderr, "You need to install python-glade2 and/or pygtk2",
+    print >>sys.stderr, "(gtk2) or set your PYTHONPATH correctly."
+    print >>sys.stderr, "try: export PYTHONPATH=",
+    print >>sys.stderr, "/usr/local/lib/python2.4/site-packages/"
+    sys.exit(1)
+
 from olive.frontend.gtk import OliveGtk
 
 app = OliveGtk()

=== modified file 'olive/frontend/gtk/commit.py'
--- olive/frontend/gtk/commit.py	2006-07-24 14:32:01 +0000
+++ olive/frontend/gtk/commit.py	2006-07-25 12:38:56 +0000
@@ -88,26 +88,31 @@
     
     # This code is from Jelmer Vernooij's bzr-gtk branch
     def _create_file_view(self):
-        self.file_store = gtk.ListStore(gobject.TYPE_BOOLEAN, gobject.TYPE_STRING, gobject.TYPE_STRING)
+        self.file_store = gtk.ListStore(gobject.TYPE_BOOLEAN,
+                                        gobject.TYPE_STRING,
+                                        gobject.TYPE_STRING)
         self.file_view = self.glade.get_widget('treeview_commit_select')
         self.file_view.set_model(self.file_store)
         crt = gtk.CellRendererToggle()
         crt.set_property("activatable", True)
         crt.connect("toggled", self._toggle_commit, self.file_store)
-        self.file_view.append_column(gtk.TreeViewColumn("Commit",crt,active=0))
-        self.file_view.append_column(gtk.TreeViewColumn("Path",gtk.CellRendererText(),text=1))
-        self.file_view.append_column(gtk.TreeViewColumn("Type",gtk.CellRendererText(),text=2))
+        self.file_view.append_column(gtk.TreeViewColumn("Commit",
+                                     crt, active=0))
+        self.file_view.append_column(gtk.TreeViewColumn("Path",
+                                     gtk.CellRendererText(), text=1))
+        self.file_view.append_column(gtk.TreeViewColumn("Type",
+                                     gtk.CellRendererText(), text=2))
 
-        for path, id, kind in self.delta.added:
+        for path, _, _ in self.delta.added:
             self.file_store.append([ True, path, "added" ])
 
-        for path, id, kind in self.delta.removed:
+        for path, _, _ in self.delta.removed:
             self.file_store.append([ True, path, "removed" ])
 
-        for oldpath, newpath, id, kind, text_modified, meta_modified in self.delta.renamed:
+        for oldpath, _, _, _, _, _ in self.delta.renamed:
             self.file_store.append([ True, oldpath, "renamed"])
 
-        for path, id, kind, text_modified, meta_modified in self.delta.modified:
+        for path, _, _, _, _ in self.delta.modified:
             self.file_store.append([ True, path, "modified"])
     
     def _get_specific_files(self):
@@ -115,7 +120,7 @@
         it = self.file_store.get_iter_first()
         while it:
             if self.file_store.get_value(it, 0):
-                ret.append(self.file_store.get_value(it,1))
+                ret.append(self.file_store.get_value(it, 1))
             it = self.file_store.iter_next(it)
 
         return ret

=== modified file 'olive/frontend/gtk/push.py'
--- olive/frontend/gtk/push.py	2006-07-24 14:32:01 +0000
+++ olive/frontend/gtk/push.py	2006-07-25 12:38:56 +0000
@@ -115,10 +115,10 @@
                 return
             
             try:
-                commit.push(self.comm.get_path(), location,
-                            self.check_remember.get_active(),
-                            self.check_overwrite.get_active(),
-                            self.check_create.get_active())
+                revs = commit.push(self.comm.get_path(), location,
+                                   self.check_remember.get_active(),
+                                   self.check_overwrite.get_active(),
+                                   self.check_create.get_active())
             except errors.NotBranchError:
                 dialog.error_dialog('Directory is not a branch.')
                 return
@@ -138,6 +138,7 @@
             pass
         
         self.close()
+        dialog.info_dialog('%d revision(s) pushed.' % revs)
     
     def close(self, widget=None):
         self.window.destroy()

